@@ -1,21 +1,8 @@
 /*
- *   Copyright 2013 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "wallpaperinterface.h"
 
@@ -23,13 +10,13 @@
 #include <kdeclarative/configpropertymap.h>
 #include <kdeclarative/qmlobjectsharedengine.h>
 
-#include <kactioncollection.h>
-#include <kdesktopfile.h>
+#include <KActionCollection>
 #include <KConfigLoader>
+#include <KDesktopFile>
 
 #include <QDebug>
-#include <QQmlExpression>
 #include <QQmlContext>
+#include <QQmlExpression>
 #include <QQmlProperty>
 
 #include <Plasma/PluginLoader>
@@ -38,15 +25,15 @@
 QHash<QObject *, WallpaperInterface *> WallpaperInterface::s_rootObjects = QHash<QObject *, WallpaperInterface *>();
 
 WallpaperInterface::WallpaperInterface(ContainmentInterface *parent)
-    : QQuickItem(parent),
-      m_containmentInterface(parent),
-      m_qmlObject(0),
-      m_configuration(0),
-      m_configLoader(0)
+    : QQuickItem(parent)
+    , m_containmentInterface(parent)
+    , m_qmlObject(nullptr)
+    , m_configuration(nullptr)
+    , m_configLoader(nullptr)
 {
     m_actions = new KActionCollection(this);
 
-    //resize at the beginning to avoid as much resize events as possible
+    // resize at the beginning to avoid as much resize events as possible
     if (parent) {
         setSize(QSizeF(parent->width(), parent->height()));
     }
@@ -54,9 +41,7 @@ WallpaperInterface::WallpaperInterface(ContainmentInterface *parent)
     if (!m_containmentInterface->containment()->wallpaper().isEmpty()) {
         syncWallpaperPackage();
     }
-    connect(m_containmentInterface->containment(), &Plasma::Containment::wallpaperChanged,
-            this, &WallpaperInterface::syncWallpaperPackage);
-
+    connect(m_containmentInterface->containment(), &Plasma::Containment::wallpaperChanged, this, &WallpaperInterface::syncWallpaperPackage);
 }
 
 WallpaperInterface::~WallpaperInterface()
@@ -68,8 +53,7 @@ WallpaperInterface::~WallpaperInterface()
 
 QList<KPluginMetaData> WallpaperInterface::listWallpaperMetadataForMimetype(const QString &mimetype, const QString &formFactor)
 {
-    auto filter = [&mimetype, &formFactor](const KPluginMetaData &md) -> bool
-    {
+    auto filter = [&mimetype, &formFactor](const KPluginMetaData &md) -> bool {
         if (!formFactor.isEmpty() && !md.value(QStringLiteral("X-Plasma-FormFactors")).contains(formFactor)) {
             return false;
         }
@@ -96,7 +80,7 @@ KDeclarative::ConfigPropertyMap *WallpaperInterface::configuration() const
 KConfigLoader *WallpaperInterface::configScheme()
 {
     if (!m_configLoader) {
-        //FIXME: do we need "mainconfigxml" in wallpaper packagestructures?
+        // FIXME: do we need "mainconfigxml" in wallpaper packagestructures?
         const QString xmlPath = m_pkg.filePath("config", QStringLiteral("main.xml"));
 
         KConfigGroup cfg = m_containmentInterface->containment()->config();
@@ -104,7 +88,7 @@ KConfigLoader *WallpaperInterface::configScheme()
         cfg = KConfigGroup(&cfg, m_wallpaperPlugin);
 
         if (xmlPath.isEmpty()) {
-            m_configLoader = new KConfigLoader(cfg, 0, this);
+            m_configLoader = new KConfigLoader(cfg, nullptr, this);
         } else {
             QFile file(xmlPath);
             m_configLoader = new KConfigLoader(cfg, &file, this);
@@ -116,8 +100,7 @@ KConfigLoader *WallpaperInterface::configScheme()
 
 void WallpaperInterface::syncWallpaperPackage()
 {
-    if (m_wallpaperPlugin == m_containmentInterface->containment()->wallpaper() &&
-            m_qmlObject->rootObject()) {
+    if (m_wallpaperPlugin == m_containmentInterface->containment()->wallpaper() && m_qmlObject->rootObject()) {
         return;
     }
 
@@ -138,10 +121,12 @@ void WallpaperInterface::syncWallpaperPackage()
         return;
     }
 
-    if (m_configLoader) m_configLoader->deleteLater();
-    if (m_configuration) m_configuration->deleteLater();
-    m_configLoader = 0;
-    m_configuration = 0;
+    if (m_configLoader)
+        m_configLoader->deleteLater();
+    if (m_configuration)
+        m_configuration->deleteLater();
+    m_configLoader = nullptr;
+    m_configuration = nullptr;
     if (configScheme()) {
         m_configuration = new KDeclarative::ConfigPropertyMap(configScheme(), this);
     }
@@ -156,7 +141,7 @@ void WallpaperInterface::syncWallpaperPackage()
         m_qmlObject->setTranslationDomain(QLatin1String("plasma_wallpaper_") + m_pkg.metadata().pluginId());
     }
 
-    //initialize with our size to avoid as much resize events as possible
+    // initialize with our size to avoid as much resize events as possible
     QVariantHash props;
     props[QStringLiteral("width")] = width();
     props[QStringLiteral("height")] = height();
@@ -165,13 +150,13 @@ void WallpaperInterface::syncWallpaperPackage()
 
 void WallpaperInterface::loadFinished()
 {
-    if (m_qmlObject->mainComponent() &&
-            m_qmlObject->rootObject() &&
-            !m_qmlObject->mainComponent()->isError()) {
+    if (m_qmlObject->mainComponent() //
+        && m_qmlObject->rootObject() //
+        && !m_qmlObject->mainComponent()->isError()) {
         m_qmlObject->rootObject()->setProperty("z", -1000);
         m_qmlObject->rootObject()->setProperty("parent", QVariant::fromValue(this));
 
-        //set anchors
+        // set anchors
         QQmlExpression expr(m_qmlObject->engine()->rootContext(), m_qmlObject->rootObject(), QStringLiteral("parent"));
         QQmlProperty prop(m_qmlObject->rootObject(), QStringLiteral("anchors.fill"));
         prop.write(expr.evaluate());
@@ -180,14 +165,14 @@ void WallpaperInterface::loadFinished()
         qWarning() << "Error loading the wallpaper" << m_qmlObject->mainComponent()->errors();
         s_rootObjects.remove(m_qmlObject->engine());
         m_qmlObject->deleteLater();
-        m_qmlObject = 0;
+        m_qmlObject = nullptr;
 
     } else {
         qWarning() << "Error loading the wallpaper, package not found";
     }
 
-    emit packageChanged();
-    emit configurationChanged();
+    Q_EMIT packageChanged();
+    Q_EMIT configurationChanged();
 }
 
 QList<QAction *> WallpaperInterface::contextualActions() const
@@ -259,11 +244,16 @@ void WallpaperInterface::executeAction(const QString &name)
     }
 }
 
-WallpaperInterface * WallpaperInterface::qmlAttachedProperties(QObject* object)
+WallpaperInterface *WallpaperInterface::qmlAttachedProperties(QObject *object)
 {
-    //at the moment of the attached object creation, the root item is the only one that hasn't a parent
-    //only way to avoid creation of this attached for everybody but the root item
+    // at the moment of the attached object creation, the root item is the only one that hasn't a parent
+    // only way to avoid creation of this attached for everybody but the root item
     return object->parent() ? nullptr : s_rootObjects.value(QtQml::qmlEngine(object));
 }
 
+bool WallpaperInterface::isLoading() const
+{
+    return m_loading;
+}
+
 #include "moc_wallpaperinterface.cpp"
